#!/usr/bin/perl
#
# Merges the configuration file fragments for
# and exim build together and spits out a list
# of build variable directives.
#
use strict;
use FileHandle;

sub read_file {
  my $filename = shift;
  my $vars = shift;

  print "# Start $filename\n";
  my $fh = FileHandle->new($filename, 'r') || die $!;
  while (<$fh>) {
    chomp;
    if (/^\s*include\(([^\)]+)\)/) {
      read_file($1, $vars);
    } elsif (/^\s*(\w+)\s*(\+?=)\s*(.*)/) {
      my $add = ($2 eq '+=');
      my $var = $1;
      my $val = $3;
      $val =~ s/\$\{(\w+)\}/$vars->{$1}/e;
      if ($add && exists($vars->{$var})) {
	$vars->{$var} .= ' ' . $val;
      } else {
	$vars->{$var} = $val;
      }
    }
  }
  print "# End $filename\n";
}

# main
{
  my $vars = {};
  while($_ = shift) {
    read_file($_, $vars);
  }
  my($k, $v);
  while(($k, $v) = each %{$vars}) {
    print "$k=$v\n";
  }
}
